import re
import string
def clean_text(text):
    text = text.lower()
    text = re.sub(';' , ' ; ' , text)
    text = re.sub(',' , ' , ' , text)
    text = re.sub('-' ,  ' - ' , text)
    text = re.sub('\d','',text) #odstranění čísel
    text = re.sub('[%s]' % re.escape(string.punctuation), ' ', text)
    return text





from setuptools import setup

setup(
    name="anasim",
    version="0.0.9",
    author="david.sulc",
    author_email="sulda.str@gmail.com",
    # py_modules=['text'],
    # package_dir={'':'anasim'}
    packages=['anasim']
)
